@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.7.4.3';
+    return '1.7.5';
   }
 
   function GetHelp()
