@@ -147,7 +147,8 @@ if (is_array($worddiff)) {
 
 if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = $curcontent->GetPropertyValue($description_block);
-    $desc = preg_replace('/[\n\r]/','',$desc);
+    $desc = preg_replace('/[\n\r]/',' ',$desc);
+    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
@@ -163,7 +164,9 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     }
     $contentBasic2 = $curcontent->GetPropertyValue('content_en');
     $desc = $contentBasic2 . $countVars2;
-    $desc = preg_replace('/[\n\r]/','',$desc);
+    $desc = preg_replace('/[\n\r]/',' ',$desc);
+    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
+    $desc = trim($desc);
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
@@ -181,7 +184,8 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     }
     $contentBasic2 = $curcontent->GetPropertyValue('content_en');
     $desc = $contentBasic2 . $countVars2;
-    $desc = preg_replace('/[\n\r]/','',$desc);
+    $desc = preg_replace('/[\n\r]/',' ',$desc);
+    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
@@ -196,9 +200,9 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
 
 
 ///// XML LANGUAGE /////
-$monkey = $this->GetPreference('html_title','en');
+$xmlLang = $this->GetPreference('html_title','en');
 $lang_count = '0';
-if (preg_match('/{/', $monkey)) {
+if (preg_match('/{/', $xmlLang)) {
     $this->smarty->assign('html_title', $lang_block);
     $lang_block = str_replace('{$','',$lang_block);
     $lang_block = str_replace('}','',$lang_block);
@@ -227,6 +231,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('standard_title', $this->GetPreference('standard_title','1'));
    $this->smarty->assign('dublin_title', $this->GetPreference('dublin_title','0'));
    $this->smarty->assign('opengraph_title', $this->GetPreference('opengraph_title','0'));
+   $this->smarty->assign('touchicon_title', $this->GetPreference('touchicon_title','0'));
    $this->smarty->assign('fullscreen_title', $this->GetPreference('fullscreen_title','-1'));
    $this->smarty->assign('statusbar_title', $this->GetPreference('statusbar_title','-1'));
    $this->smarty->assign('phoneno_title', $this->GetPreference('phoneno_title','-1'));
@@ -245,6 +250,8 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('longitude_title', $this->GetPreference('longitude_title',''));
    $this->smarty->assign('ogtype_title', $this->GetPreference('ogtype_title',''));
    $this->smarty->assign('ogimage_title', $this->GetPreference('ogimage_title','0'));
+   $this->smarty->assign('favicon_title', $this->GetPreference('favicon_title','0'));
+   $this->smarty->assign('favsize_title', $this->GetPreference('favsize_title','0'));
    $this->smarty->assign('fbadmin_title', $this->GetPreference('fbadmin_title',''));
    $this->smarty->assign('fbapp_title', $this->GetPreference('fbapp_title',''));
    $this->smarty->assign('analyticstype_title', $this->GetPreference('analyticstype_title','-1'));
