@@ -24,6 +24,7 @@ $this->SetPreference('dublin_title',
 $this->SetPreference('opengraph_title',
 		     (isset($params['opengraph_title'])?'1':'0'));
 
+$this->SetPreference('touchicon_title', $params['touchicon_title']);
 $this->SetPreference('fullscreen_title', $params['fullscreen_title']);
 $this->SetPreference('statusbar_title', $params['statusbar_title']);
 $this->SetPreference('phoneno_title', $params['phoneno_title']);
@@ -43,6 +44,8 @@ $this->SetPreference('latitude_title', $params['latitude_title']);
 $this->SetPreference('longitude_title', $params['longitude_title']);
 $this->SetPreference('ogtype_title', $params['ogtype_title']);
 $this->SetPreference('ogimage_title', $params['ogimage_title']);
+$this->SetPreference('favicon_title', $params['favicon_title']);
+$this->SetPreference('favsize_title', $params['favsize_title']);
 $this->SetPreference('fbadmin_title', $params['fbadmin_title']);
 $this->SetPreference('fbapp_title', $params['fbapp_title']);
 
