@@ -18,6 +18,9 @@ while ($file = readdir($dp)) {
     if (strpos(substr($file, -5),'.jpeg') !== false) {
         $files_list[$file] = $file;
     }
+    if (strpos(substr($file, -5),'.ico') !== false) {
+        $files_list[$file] = $file;
+    }
 }
 closedir($dp);
 
@@ -48,7 +51,10 @@ $smarty->assign('delimiter_title_help',$this->Lang('delimiter_title_help'));
 $smarty->assign('block_title_help',$this->Lang('block_title_help'));
 $smarty->assign('meta_block_title_help',$this->Lang('meta_block_title_help'));
 $smarty->assign('content_var_title_help',$this->Lang('content_var_title_help'));
+$smarty->assign('touchicon_title_help',$this->Lang('touchicon_title_help'));
 $smarty->assign('ogimage_title_help',$this->Lang('ogimage_title_help'));
+$smarty->assign('favicon_title_help',$this->Lang('favicon_title_help'));
+$smarty->assign('favsize_title_help',$this->Lang('favsize_title_help'));
 
 $smarty->assign('title_page_smarty',$this->Lang('page_smarty'));
 $smarty->assign('input_page_smarty',$this->CreateInputText($id,'page_smarty',$this->GetPreference('page_smarty',''),50,255));
@@ -86,6 +92,9 @@ $smarty->assign('input_dublin_title', $this->CreateInputCheckbox($id,'dublin_tit
 $smarty->assign('title_opengraph_title',$this->Lang('opengraph_title'));
 $smarty->assign('input_opengraph_title', $this->CreateInputCheckbox($id,'opengraph_title','1', $this->GetPreference('opengraph_title','0')));
 
+$smarty->assign('title_touchicon_title',$this->Lang('touchicon_title'));
+$smarty->assign('input_touchicon_title',$this->CreateInputDropdown($id,'touchicon_title',$files_list,-1,$this->GetPreference('touchicon_title','')));
+
 $smarty->assign('title_fullscreen_title',$this->Lang('fullscreen_title'));
 $smarty->assign('input_fullscreen_title',$this->CreateInputDropdown($id,'fullscreen_title',$dropDown,$this->GetPreference('fullscreen_title','-1'),$this->GetPreference('fullscreen_title','-1')));
 
@@ -140,6 +149,12 @@ $smarty->assign('input_ogtype_title',$this->CreateInputText($id,'ogtype_title',$
 $smarty->assign('title_ogimage_title',$this->Lang('ogimage_title'));
 $smarty->assign('input_ogimage_title',$this->CreateInputDropdown($id,'ogimage_title',$files_list,-1,$this->GetPreference('ogimage_title','')));
 
+$smarty->assign('title_favicon_title',$this->Lang('favicon_title'));
+$smarty->assign('input_favicon_title',$this->CreateInputDropdown($id,'favicon_title',$files_list,-1,$this->GetPreference('favicon_title','')));
+
+$smarty->assign('title_favsize_title',$this->Lang('favsize_title'));
+$smarty->assign('input_favsize_title',$this->CreateInputText($id,'favsize_title',$this->GetPreference('favsize_title',''),50,255));
+
 $smarty->assign('title_fbadmin_title',$this->Lang('fbadmin_title'));
 $smarty->assign('input_fbadmin_title',$this->CreateInputText($id,'fbadmin_title',$this->GetPreference('fbadmin_title',''),50,255));
 
