@@ -109,6 +109,8 @@ $lang['jquery_true'] = 'True';
 $lang['jquery_false'] = 'False';
 $lang['dublin_title'] = 'Generate Dublin Core Meta Tags';
 $lang['opengraph_title'] = 'Generate OpenGraph Meta Tags (e.g. for Facebook Like Button)';
+$lang['touchicon_title'] = 'Website Apple touch icon';
+$lang['touchicon_title_help'] = 'Select an image from your /uploads/images directory to be used as the Apple touch icon, should be 120px x 120px .png file';
 $lang['drop_select'] = 'Please Select';
 $lang['drop_yes'] = 'Yes';
 $lang['drop_no'] = 'No';
@@ -137,6 +139,10 @@ $lang['ogtype_title'] = 'OpenGraph default page type';
 $lang['ogname_title'] = 'OpenGraph site name';
 $lang['ogimage_title'] = 'OpenGraph default image';
 $lang['ogimage_title_help'] = 'Select an image from your /uploads/images directory to be used as the default for OpenGraph pages';
+$lang['favicon_title'] = 'Website favicon';
+$lang['favicon_title_help'] = 'Select an image from your /uploads/images directory to be used as the site favicon, should be an .ico file';
+$lang['favsize_title'] = 'Website favicon sizes';
+$lang['favsize_title_help'] = 'Select your icon sizes if using multi-image ico file. i.e 16x16 32x32 64x64';
 $lang['fbadmin_title'] = 'Facebook site administrators';
 $lang['fbapp_title'] = 'Facebook application';
 $lang['key_number'] = 'Number of keywords';
@@ -190,7 +196,13 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.4 27 February 2012. Minor bug fixes and removed non working stylesheet and jquery params to avoid confusion.</li>
 <li>Version 1.7.4.1 29 February 2012. Minor bug fix and the addition of smarty use in the language field, useful for mulitlingual sites.</li>
 <li>Version 1.7.4.2 29 February 2012. Added the ability to display Apple meta tags.</li>
-<li>Version 1.7.4.3 1 March 2012. Minor bug fix.</li></ul>';
+<li>Version 1.7.4.3 1 March 2012. Minor bug fix.</li>
+<li>Version 1.7.4.4 5 March 2012. Added Favicon and Apple Touch Icon options.</li>
+<li>Version 1.7.4.6 6 March 2012. Removed invalid meta tags if HTML5 is chosen.</li>
+<li>Version 1.7.4.7 15 March 2012. Added canonical link.</li>
+<li>Version 1.7.4.8 3 April 2012. Added favicon size option for use with multi-image ico files.</li>
+<li>Version 1.7.4.9 18 May 2012. Stripping out of whitespace from descriptions added.</li>
+<li>Version 1.7.5 21 June 2012. Bug fix for 1.11 compatability.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
@@ -215,7 +227,7 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 of the license for the full disclaimer.</p>
 
 <h3>Copyright and License</h3>
-<p>Copyright &copy; 2011, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
+<p>Copyright &copy; 2012, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
 ';
 ?>
\ No newline at end of file
